@@ -73,7 +73,7 @@ def Init(luna_config_file='luna_config.yml'):
         luna_config = yaml.full_load(file)
     return luna_config
 
-def GetDeploymentConfig(luna_config, dns_name_label):
+def GetDeploymentConfig(luna_config, dns_name_label,tags):
     with open(luna_config['azureml']['workspace_config']) as file:
         documents = yaml.full_load(file)
         deployment_target = documents['deployment_target']
@@ -93,6 +93,7 @@ def GetDeploymentConfig(luna_config, dns_name_label):
             deployment_config.compute_target_name = aks_cluster
             deployment_config.namespace = dns_name_label
 
+        deployment_config.tags = tags
     return deployment_config
 
 def DeployModel():
@@ -125,7 +126,14 @@ def DeployModel():
 
         inference_config = InferenceConfig(entry_script=luna_config['code']['score'], source_directory = os.getcwd(), environment=myenv)
 
-        deployment_config = GetDeploymentConfig(luna_config, dns_name_label)
+        deployment_config = GetDeploymentConfig(
+            luna_config, 
+            dns_name_label,
+            tags={'userId': args.userId, 
+                'productName': args.productName, 
+                'deploymentName': args.deploymentName, 
+                'apiVersion':args.apiVersion,
+                'subscriptionId':args.subscriptionId})
         
         service = Model.deploy(ws, endpoint_id, [model], inference_config, deployment_config)
         service.wait_for_deployment(show_output = True)
@@ -144,7 +152,8 @@ def RunProject(azureml_workspace, entry_point, experiment_name, parameters, tags
             inputs=[],
             outputs=[],
             source_directory=os.getcwd(),
-            runconfig=run_config
+            runconfig=run_config,
+            allow_reuse=False
         )
 
         pipeline = Pipeline(workspace=azureml_workspace, steps=[trainStep])
